<?php
namespace Teknisa\PLA\Modules\Cardapio\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use \Setforms2\Shared\ORM\DateTime;

class Pla07600AprovacaoCardapioFilialService {

	public function __construct($dataSourceManager, $environment, $entityManager) {

        $this->dataSourceManager = $dataSourceManager;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }

	public function updateCtrlaprovcard($cardapio, $cardapioSelecionado, $dtaprocardifli) {

		$params = array(
            'cdservfili' => $cardapio['CDSERVFILI'],
            'cdfilial' => $cardapio['CDFILIAL'],
            'nrorg' => $this->environment->getNrOrg(),
            'dtmescardaprov' => $cardapio['DTMESCARD'],
        );

        $ctrlaprovcard = $this->entityManager->getRepository('Planejamento\Entities\Ctrlaprovcard')->findBy($params);

        if (isset($ctrlaprovcard[0])) {

        	$date = new DateTime();

       		$ctrlaprovcard[0]->setCdoperaprocardfili($this->environment->getCdOperador());
       		$ctrlaprovcard[0]->setDtaprocardfili($dtaprocardifli);
       		$ctrlaprovcard[0]->setDsobsaprocardfili($cardapioSelecionado['DSOBSAPROCARDFILI']);
       		$ctrlaprovcard[0]->setVrpuctrlaprcard($cardapio['VRCUSTPRODMAT']);
       		$ctrlaprovcard[0]->setCdtipocusto($cardapio['CDTIPOCUSTODESC']);
       		$ctrlaprovcard[0]->setDtultatu($date);
       		$ctrlaprovcard[0]->setCdoperultatu($this->environment->getCdOperador());

            $this->entityManager->persist($ctrlaprovcard[0]);
            $this->entityManager->flush();

        }

	}

    public function insertLogaprovcard($row) {

        $logaprovcard = new \Planejamento\Entities\Logaprovcard();

        $logaprovcard = $this->buildLogaprovcard($logaprovcard, $row);

        $this->entityManager->persist($logaprovcard);
        $this->entityManager->flush();

    }

    public function buildLogaprovcard($logaprovcard, $row) {

        $logaprovcard->setCdfilial($row['CDFILIAL']);
        $logaprovcard->setCdservfili($row['CDSERVFILI']);
        $logaprovcard->setDtmescardaprovlog($row['DTMESCARD']);
        $logaprovcard->setDtlogaprovcard(new DateTime());
        $logaprovcard->setCdoperlogaprovcard($this->environment->getCdOperador());
        $logaprovcard->setIdsituopercard($row['IDSITUOPERCARD']);
        $logaprovcard->setIdtipoopercard('F');
        $logaprovcard->setNrorg($this->environment->getNrOrg());
        $logaprovcard->setDtinclusao(new DateTime());
        $logaprovcard->setDtultatu(new DateTime());
        $logaprovcard->setCdoperinclusao($this->environment->getCdOperador());

        return $logaprovcard;
    }

    public function operadorTemPermissaoAprovarForaDaMeta() {

        $filterCriteria = new FilterCriteria('opergrupop');
        $filterCriteria->addCondition('CDOPERADOR', $this->environment->getCdOperador());
        $filterCriteria->addCondition('CDGRUPOPER', $this->retornaGrupoAprovacaoForaDaMeta());

        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();

        return isset($rows[0]) ? true : false;
    }

    public function retornaGrupoAprovacaoForaDaMeta() {

        $filterCriteria = new FilterCriteria('autgrupop');
        $filterCriteria->addCondition('IDAUTGRUPOP', 'LCMR');
        $filterCriteria->addCondition('NRAUTGRUPOP', '000');
        $filterCriteria->addCondition('NRORG', $this->environment->getNrOrg());

        $dataSet = $this->dataSourceManager->findBy($filterCriteria);
        $rows = $dataSet->getRows();

        return isset($rows[0]) ? $rows[0]['CDGRUPOPER'] : null;

    }

    public function insertObsaprovcardfili($filial, $observacao, $dataCardapio) {

        $obsaprovcardfili = $this->retornaObsaprovcardfili($filial, $dataCardapio);

        if (isset($obsaprovcardfili[0])) {

            $obsaprovcardfili = $this->setObsaprovcardfili($obsaprovcardfili[0], $filial, $observacao, $dataCardapio);

        } else {

            $obsaprovcardfili = $this->novoObsaprovcardfili($filial, $observacao, $dataCardapio);

        }

        $this->entityManager->persist($obsaprovcardfili);
        $this->entityManager->flush();

    }

    public function setObsaprovcardfili($obsaprovcardfili, $filial, $observacao, $dataCardapio) {

        $date = new DateTime();

        $obsaprovcardfili->setDsgeraprocardfili($observacao);
        $obsaprovcardfili->setCdoperultatu($this->environment->getCdOperador());

        return $obsaprovcardfili;
    }

    public function novoObsaprovcardfili($filial, $observacao, $dataCardapio) {

        $obsaprovcardfili = new \Planejamento\Entities\Obsaprovcardfili();

        return $this->buildObsaprovcardfili($obsaprovcardfili, $filial, $observacao, $dataCardapio);

    }

    public function buildObsaprovcardfili($obsaprovcardfili, $filial, $observacao, $dataCardapio) {

        $obsaprovcardfili->setCdfilial($filial);
        $obsaprovcardfili->setDtmescardaprovfili($dataCardapio);
        $obsaprovcardfili->setDsgeraprocardfili($observacao);
        $obsaprovcardfili->setNrorg($this->environment->getNrOrg());
        $obsaprovcardfili->setDtinclusao(new DateTime());
        $obsaprovcardfili->setDtultatu(new DateTime());
        $obsaprovcardfili->setCdoperinclusao($this->environment->getCdOperador());

        return $obsaprovcardfili;

    }

    public function retornaObsaprovcardfili($filial, $dataCardapio) {

        $params = array(
            'cdfilial' => $filial,
            'nrorg' => $this->environment->getNrOrg(),
            'dtmescardaprovfili' => $dataCardapio,
        );

        return $this->entityManager->getRepository('Planejamento\Entities\Obsaprovcardfili')->findBy($params);
    }

    public function removeObsaprovcardfili($filial, $dataCardapio) {

        $obsaprovcardfili = $this->retornaObsaprovcardfili($filial, $dataCardapio);

        if (isset($obsaprovcardfili[0])) {

            $this->entityManager->remove($obsaprovcardfili[0]);
            $this->entityManager->flush();

        }
    }

}